@@ -93,6 +93,8 @@ Some well known keys used by Launchpad in its OOPS reports::
 """
 
 
+from __future__ import absolute_import, print_function
+
 __all__ = [
     'Config',
     ]
@@ -102,8 +104,8 @@ __metaclass__ = type
 from copy import deepcopy
 import warnings
 
-from createhooks import default_hooks
-from publishers import (
+from oops.createhooks import default_hooks
+from oops.publishers import (
     convert_result_to_list,
     publish_to_many,
     )
