@@ -15,6 +15,8 @@
 
 """Generic publisher support and utility code."""
 
+from __future__ import absolute_import, print_function
+
 __metaclass__ = type
 
 __all__ = [
@@ -28,7 +30,7 @@ from pprint import pformat
 
 
 def pprint_to_stream(stream):
-    """Pretty print reports to stream.
+    """Pretty print reports to text stream.
     
     Reports will be given an id by hashing the report if none is present.
     """
@@ -36,7 +38,7 @@ def pprint_to_stream(stream):
         report = dict(report)
         output = pformat(report)
         if not report.get('id'):
-            report['id'] = md5(output).hexdigest()
+            report['id'] = md5(output.encode('UTF-8')).hexdigest()
             output = pformat(report)
         stream.write(output)
         stream.write('\n')
